@@ -15,9 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
- * $Id: demux_matroska.c,v 1.53 2007/03/12 16:27:21 dgp85 Exp $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  *
  * demultiplexer for matroska streams
  *
@@ -25,7 +23,6 @@
  *   more decoders init
  *   metadata
  *   non seekable input plugins support
- *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -68,13 +65,6 @@
 #define MAX(a, b)	((a)>(b)?(a):(b))
 #endif
 
-/* FOURCC will be manipulated using machine endian */
-#ifdef WORDS_BIGENDIAN
-#define meFOURCC BE_FOURCC
-#else
-#define meFOURCC LE_FOURCC
-#endif
-
 typedef struct {
   int                  track_num;
   off_t               *pos;
@@ -789,7 +779,7 @@ static int vobsub_parse_custom_colors(matroska_track_t *t, const char *start) {
     use_custom_colors = 1;
   else if (!strncasecmp(start, "OFF", 3) || (*start == '0'))
     use_custom_colors = 0;
-  lprintf("VobSub custom colors: %s\n", use_custom_colors ? "ON" : "OFF");
+  lprintf("VobSub custom colours: %s\n", use_custom_colors ? "ON" : "OFF");
   if ((start = strstr(start, "colors:")) != NULL) {
     start += 7;
     while (isspace(*start))
@@ -803,7 +793,7 @@ static int vobsub_parse_custom_colors(matroska_track_t *t, const char *start) {
     }
     if (i == 4) {
       t->sub_track->custom_colors = 4;
-      lprintf("VobSub colors: %06x,%06x,%06x,%06x\n", t->sub_track->colors[0],
+      lprintf("VobSub colours: %06x,%06x,%06x,%06x\n", t->sub_track->colors[0],
               t->sub_track->colors[1], t->sub_track->colors[2],
               t->sub_track->colors[3]);
     }
@@ -863,7 +853,7 @@ static void init_codec_vobsub(demux_matroska_t *this,
         things_found |= vobsub_parse_size(track, start);
       else if (!strncasecmp(start, "palette:", 8))
         things_found |= vobsub_parse_palette(track, start);
-      else if (!strncasecmp(start, "custom colors:", 14))
+      else if (!strncasecmp(start, "custom colours:", 14))
         things_found |= vobsub_parse_custom_colors(track, start);
       else if (!strncasecmp(start, "forced subs:", 12))
         things_found |= vobsub_parse_forced_subs(track, start);
@@ -1191,8 +1181,10 @@ static int parse_track_entry(demux_matroska_t *this, matroska_track_t *track) {
       case MATROSKA_ID_TR_CODECID: {
         char *codec_id = malloc (elem.len + 1);
         lprintf("CodecID\n");
-        if (!ebml_read_ascii(ebml, &elem, codec_id))
+        if (!ebml_read_ascii(ebml, &elem, codec_id)) {
+	  free(codec_id);
           return 0;
+	}
         codec_id[elem.len] = '\0';
         track->codec_id = codec_id;
       }
@@ -1201,8 +1193,10 @@ static int parse_track_entry(demux_matroska_t *this, matroska_track_t *track) {
       case MATROSKA_ID_TR_CODECPRIVATE: {
         char *codec_private = malloc (elem.len);
         lprintf("CodecPrivate\n");
-        if (!ebml_read_binary(ebml, &elem, codec_private))
+        if (!ebml_read_binary(ebml, &elem, codec_private)) {
+	  free(codec_private);
           return 0;
+	}
         track->codec_private = codec_private;
         track->codec_private_len = elem.len;
       }
@@ -1211,8 +1205,10 @@ static int parse_track_entry(demux_matroska_t *this, matroska_track_t *track) {
       case MATROSKA_ID_TR_LANGUAGE: {
         char *language = malloc (elem.len + 1);
         lprintf("Language\n");
-        if (!ebml_read_ascii(ebml, &elem, language))
+        if (!ebml_read_ascii(ebml, &elem, language)) {
+	  free(language);
           return 0;
+	}
         language[elem.len] = '\0';
         track->language = language;
       }
@@ -1319,7 +1315,7 @@ static int parse_track_entry(demux_matroska_t *this, matroska_track_t *track) {
       /* create a bitmap info header struct for MPEG 4 */
       bih = malloc(sizeof(xine_bmiheader) + track->codec_private_len);
       bih->biSize = sizeof(xine_bmiheader) + track->codec_private_len;
-      bih->biCompression = meFOURCC('M', 'P', '4', 'S');
+      bih->biCompression = ME_FOURCC('M', 'P', '4', 'S');
       bih->biWidth = track->video_track->pixel_width;
       bih->biHeight = track->video_track->pixel_height;
       _x_bmiheader_le2me(bih);
@@ -1340,7 +1336,7 @@ static int parse_track_entry(demux_matroska_t *this, matroska_track_t *track) {
       /* create a bitmap info header struct for h264 */
       bih = malloc(sizeof(xine_bmiheader) + track->codec_private_len);
       bih->biSize = sizeof(xine_bmiheader) + track->codec_private_len;
-      bih->biCompression = meFOURCC('a', 'v', 'c', '1');
+      bih->biCompression = ME_FOURCC('a', 'v', 'c', '1');
       bih->biWidth = track->video_track->pixel_width;
       bih->biHeight = track->video_track->pixel_height;
       _x_bmiheader_le2me(bih);
@@ -1863,7 +1859,7 @@ static int parse_block (demux_matroska_t *this, uint64_t block_size,
 
   gap = flags & 1;
   lacing = (flags >> 1) & 0x3;
-  fprintf(stderr, "lacing: %x\n", lacing);
+/*fprintf(stderr, "lacing: %x\n", lacing);*/
 
   if (!find_track_by_id(this, (int)track_num, &track)) {
      xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
