@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  */
 
 /*
@@ -30,8 +30,6 @@
  *   (C) Alex Beregszaszi <alex@naxine.org>
  *   
  *   Based on FFmpeg's libav/rm.c.
- *
- * $Id: demux_real.c,v 1.113 2007/02/20 00:34:56 dgp85 Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -806,8 +804,27 @@ static int demux_real_parse_references( demux_real_t *this) {
   
   lprintf("received %d bytes [%s]\n", buf_used, buf);
 
-  for(i=0;i<buf_used;i++) {
-
+  if (!strncmp(buf,"http://",7))
+  {
+    i = 0;
+    while (buf[i])
+    {
+      j = i;
+      while (buf[i] && !isspace(buf[i]))
+	++i; /* skip non-space */
+      len = buf[i];
+      buf[i] = 0;
+      if (strncmp (buf + j, "http://", 7) || (i - j) < 8)
+        break; /* stop at the first non-http reference */
+      lprintf("reference [%s] found\n", buf + j);
+      _x_demux_send_mrl_reference (this->stream, 0, buf + j, NULL, 0, 0);
+      buf[i] = (char) len;
+      while (buf[i] && isspace(buf[i]))
+	++i; /* skip spaces */
+    }
+  }
+  else for (i = 0; i < buf_used; ++i)
+  {
     /* "--stop--" is used to have pnm alternative for old real clients
      * new real clients will stop processing the file and thus use
      * rtsp protocol.
@@ -1534,7 +1551,8 @@ static int real_check_stream_type(uint8_t *buf, int len)
     return 1;
 
   buf[len] = '\0';
-  if( strstr(buf,"pnm://") || strstr(buf,"rtsp://") || strstr(buf,"<smil>") )
+  if( strstr(buf,"pnm://") || strstr(buf,"rtsp://") || strstr(buf,"<smil>") ||
+      !strncmp(buf,"http://",7) )
     return 2;
 
   return 0;
