@@ -15,9 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
- * $Id: demux_sputext.c,v 1.53 2007/01/19 01:05:25 dgp85 Exp $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  *
  * code based on old libsputext/xine_decoder.c
  *
@@ -384,31 +382,6 @@ static subtitle_t *sub_read_line_subrip(demux_sputext_t *this,subtitle_t *curren
           } else
             temp_line[temp_index++]=*p;
           break;
-        case '{':
-#if 0 /* italic not implemented in renderer, ignore them for now */
-          if(!strncmp(p,"{\\i1}",5) && temp_index+3<SUB_BUFSIZE) {
-            temp_line[temp_index++]='<';
-            temp_line[temp_index++]='i';
-            temp_line[temp_index++]='>';
-#else
-          if(!strncmp(p,"{\\i1}",5)) {
-#endif
-            p+=4;
-          }
-#if 0 /* italic not implemented in renderer, ignore them for now */
-          else if(!strncmp(p,"{\\i0}",5) && temp_index+4<SUB_BUFSIZE) {
-            temp_line[temp_index++]='<';
-            temp_line[temp_index++]='/';
-            temp_line[temp_index++]='i';
-            temp_line[temp_index++]='>';
-#else
-          else if(!strncmp(p,"{\\i0}",5)) {
-#endif
-            p+=4;
-          }
-          else
-            temp_line[temp_index++]=*p;
-          break;
         case '\r': /* just ignore '\r's */
           break;
         case '\n':
