@@ -15,12 +15,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  *
  * Demuxer helper functions
  * hide some xine engine details from demuxers and reduce code duplication
- *
- * $Id: demux.c,v 1.65 2006/12/03 19:23:16 miguelfreitas Exp $ 
  */
 
 
@@ -448,7 +446,7 @@ int _x_demux_read_header( input_plugin_t *input, unsigned char *buffer, off_t si
   return read_size;
 }
 
-int _x_demux_check_extension (char *mrl, char *extensions){
+int _x_demux_check_extension (const char *mrl, const char *extensions){
   char *last_dot, *e, *ext_copy, *ext_work;
 
   ext_copy = strdup(extensions);
